# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.playback_error import PlaybackError  # noqa: E501
from mozart_api.rest import ApiException


class TestPlaybackError(unittest.TestCase):
    """PlaybackError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PlaybackError
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.playback_error.PlaybackError()  # noqa: E501
        if include_optional:
            return PlaybackError(
                error="0",
                item=mozart_api.models.playback_content_metadata.PlaybackContentMetadata(
                    album_name="0",
                    art=[
                        mozart_api.models.art.Art(
                            has_local_image=True,
                            key="0",
                            size="0",
                            type="0",
                            url="0",
                        )
                    ],
                    artist_name="0",
                    bitdepth=56,
                    bitrate=56,
                    container_name="0",
                    encoding="pcm",
                    genre="0",
                    id=56,
                    input_channel_processing="dolbySurround",
                    input_channels="0",
                    organization="0",
                    output_channel_processing="Direct",
                    output_channels="0",
                    queue_id="0",
                    remote_leader=mozart_api.models.beolink_leader.BeolinkLeader(
                        friendly_name="0",
                        jid="2714.1200304.26451293@products.bang-olufsen.com",
                    ),
                    remote_source="0",
                    samplerate=56,
                    source="0",
                    source_internal_id="0",
                    title="0",
                    total_duration=56,
                    total_duration_seconds=56,
                    track=56,
                    track_count=56,
                    uri="0",
                ),
            )
        else:
            return PlaybackError()

    def testPlaybackError(self):
        """Test PlaybackError"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.source_type_enum import SourceTypeEnum
from mozart_api.models.stand_position import StandPosition
from mozart_api.models.play_queue_settings import PlayQueueSettings
from mozart_api.models.play_queue_item import PlayQueueItem

from mozart_api.configuration import Configuration


class Action(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "button_name": "str",
        "content_id": "str",
        "deezer_user_id": "str",
        "listening_mode_id": "int",
        "preset_key": "str",
        "queue_item": "PlayQueueItem",
        "queue_settings": "PlayQueueSettings",
        "radio_station_id": "str",
        "source": "SourceTypeEnum",
        "speaker_group_id": "str",
        "stand_position": "StandPosition",
        "stop_duration": "int",
        "tone_name": "str",
        "type": "str",
        "volume_level": "int",
    }

    attribute_map = {
        "button_name": "buttonName",
        "content_id": "contentId",
        "deezer_user_id": "deezerUserId",
        "listening_mode_id": "listeningModeId",
        "preset_key": "presetKey",
        "queue_item": "queueItem",
        "queue_settings": "queueSettings",
        "radio_station_id": "radioStationId",
        "source": "source",
        "speaker_group_id": "speakerGroupId",
        "stand_position": "standPosition",
        "stop_duration": "stopDuration",
        "tone_name": "toneName",
        "type": "type",
        "volume_level": "volumeLevel",
    }

    def __init__(
        self,
        button_name: Optional[str] = None,
        content_id: Optional[str] = None,
        deezer_user_id: Optional[str] = None,
        listening_mode_id: Optional[int] = None,
        preset_key: Optional[str] = None,
        queue_item: Optional[PlayQueueItem] = None,
        queue_settings: Optional[PlayQueueSettings] = None,
        radio_station_id: Optional[str] = None,
        source: Optional[SourceTypeEnum] = None,
        speaker_group_id: Optional[str] = None,
        stand_position: Optional[StandPosition] = None,
        stop_duration: Optional[int] = None,
        tone_name: Optional[str] = None,
        type: Optional["Action.LTypeType"] = None,
        volume_level: Optional[int] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Action - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._button_name = None
        self._content_id = None
        self._deezer_user_id = None
        self._listening_mode_id = None
        self._preset_key = None
        self._queue_item = None
        self._queue_settings = None
        self._radio_station_id = None
        self._source = None
        self._speaker_group_id = None
        self._stand_position = None
        self._stop_duration = None
        self._tone_name = None
        self._type = None
        self._volume_level = None
        self.discriminator = None

        self.button_name = button_name
        self.content_id = content_id
        self.deezer_user_id = deezer_user_id
        if listening_mode_id is not None:
            self.listening_mode_id = listening_mode_id
        self.preset_key = preset_key
        if queue_item is not None:
            self.queue_item = queue_item
        if queue_settings is not None:
            self.queue_settings = queue_settings
        self.radio_station_id = radio_station_id
        if source is not None:
            self.source = source
        if speaker_group_id is not None:
            self.speaker_group_id = speaker_group_id
        if stand_position is not None:
            self.stand_position = stand_position
        self.stop_duration = stop_duration
        self.tone_name = tone_name
        self.type = type
        self.volume_level = volume_level

    @property
    def button_name(self):
        # type: () -> str
        """Gets the button_name of this Action.  # noqa: E501

        Name of the Button used for button-press types ('buttonShortPress')  # noqa: E501

        :return: The button_name of this Action.  # noqa: E501
        :rtype: str
        """
        return self._button_name

    @button_name.setter
    def button_name(self, button_name):
        # type: (str) -> None
        """Sets the button_name of this Action.

        Name of the Button used for button-press types ('buttonShortPress')  # noqa: E501

        :param button_name: The button_name of this Action.  # noqa: E501
        :type button_name: str
        :rtype: None
        """
        allowed_values = [
            None,
            "preset1",
            "preset2",
            "preset3",
            "preset4",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and button_name not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `button_name` ({0}), must be one of {1}".format(  # noqa: E501
                    button_name, allowed_values
                )
            )

        self._button_name = button_name

    @property
    def content_id(self):
        # type: () -> str
        """Gets the content_id of this Action.  # noqa: E501

        Id of content only used for 'type=triggerContent'  # noqa: E501

        :return: The content_id of this Action.  # noqa: E501
        :rtype: str
        """
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        # type: (str) -> None
        """Sets the content_id of this Action.

        Id of content only used for 'type=triggerContent'  # noqa: E501

        :param content_id: The content_id of this Action.  # noqa: E501
        :type content_id: str
        :rtype: None
        """

        self._content_id = content_id

    @property
    def deezer_user_id(self):
        # type: () -> str
        """Gets the deezer_user_id of this Action.  # noqa: E501

        Id of user only used for 'type=deezerFlow' and is optional  # noqa: E501

        :return: The deezer_user_id of this Action.  # noqa: E501
        :rtype: str
        """
        return self._deezer_user_id

    @deezer_user_id.setter
    def deezer_user_id(self, deezer_user_id):
        # type: (str) -> None
        """Sets the deezer_user_id of this Action.

        Id of user only used for 'type=deezerFlow' and is optional  # noqa: E501

        :param deezer_user_id: The deezer_user_id of this Action.  # noqa: E501
        :type deezer_user_id: str
        :rtype: None
        """

        self._deezer_user_id = deezer_user_id

    @property
    def listening_mode_id(self):
        # type: () -> int
        """Gets the listening_mode_id of this Action.  # noqa: E501


        :return: The listening_mode_id of this Action.  # noqa: E501
        :rtype: int
        """
        return self._listening_mode_id

    @listening_mode_id.setter
    def listening_mode_id(self, listening_mode_id):
        # type: (int) -> None
        """Sets the listening_mode_id of this Action.


        :param listening_mode_id: The listening_mode_id of this Action.  # noqa: E501
        :type listening_mode_id: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and listening_mode_id is not None
            and listening_mode_id < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `listening_mode_id`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._listening_mode_id = listening_mode_id

    @property
    def preset_key(self):
        # type: () -> str
        """Gets the preset_key of this Action.  # noqa: E501

        Only used for 'type=sourcePreset'  # noqa: E501

        :return: The preset_key of this Action.  # noqa: E501
        :rtype: str
        """
        return self._preset_key

    @preset_key.setter
    def preset_key(self, preset_key):
        # type: (str) -> None
        """Sets the preset_key of this Action.

        Only used for 'type=sourcePreset'  # noqa: E501

        :param preset_key: The preset_key of this Action.  # noqa: E501
        :type preset_key: str
        :rtype: None
        """

        self._preset_key = preset_key

    @property
    def queue_item(self):
        # type: () -> PlayQueueItem
        """Gets the queue_item of this Action.  # noqa: E501


        :return: The queue_item of this Action.  # noqa: E501
        :rtype: PlayQueueItem
        """
        return self._queue_item

    @queue_item.setter
    def queue_item(self, queue_item):
        # type: (PlayQueueItem) -> None
        """Sets the queue_item of this Action.


        :param queue_item: The queue_item of this Action.  # noqa: E501
        :type queue_item: PlayQueueItem
        :rtype: None
        """

        self._queue_item = queue_item

    @property
    def queue_settings(self):
        # type: () -> PlayQueueSettings
        """Gets the queue_settings of this Action.  # noqa: E501


        :return: The queue_settings of this Action.  # noqa: E501
        :rtype: PlayQueueSettings
        """
        return self._queue_settings

    @queue_settings.setter
    def queue_settings(self, queue_settings):
        # type: (PlayQueueSettings) -> None
        """Sets the queue_settings of this Action.


        :param queue_settings: The queue_settings of this Action.  # noqa: E501
        :type queue_settings: PlayQueueSettings
        :rtype: None
        """

        self._queue_settings = queue_settings

    @property
    def radio_station_id(self):
        # type: () -> str
        """Gets the radio_station_id of this Action.  # noqa: E501

        Id of RadioStation only used for 'type=radio'  # noqa: E501

        :return: The radio_station_id of this Action.  # noqa: E501
        :rtype: str
        """
        return self._radio_station_id

    @radio_station_id.setter
    def radio_station_id(self, radio_station_id):
        # type: (str) -> None
        """Sets the radio_station_id of this Action.

        Id of RadioStation only used for 'type=radio'  # noqa: E501

        :param radio_station_id: The radio_station_id of this Action.  # noqa: E501
        :type radio_station_id: str
        :rtype: None
        """

        self._radio_station_id = radio_station_id

    @property
    def source(self):
        # type: () -> SourceTypeEnum
        """Gets the source of this Action.  # noqa: E501


        :return: The source of this Action.  # noqa: E501
        :rtype: SourceTypeEnum
        """
        return self._source

    @source.setter
    def source(self, source):
        # type: (SourceTypeEnum) -> None
        """Sets the source of this Action.


        :param source: The source of this Action.  # noqa: E501
        :type source: SourceTypeEnum
        :rtype: None
        """

        self._source = source

    @property
    def speaker_group_id(self):
        # type: () -> str
        """Gets the speaker_group_id of this Action.  # noqa: E501


        :return: The speaker_group_id of this Action.  # noqa: E501
        :rtype: str
        """
        return self._speaker_group_id

    @speaker_group_id.setter
    def speaker_group_id(self, speaker_group_id):
        # type: (str) -> None
        """Sets the speaker_group_id of this Action.


        :param speaker_group_id: The speaker_group_id of this Action.  # noqa: E501
        :type speaker_group_id: str
        :rtype: None
        """

        self._speaker_group_id = speaker_group_id

    @property
    def stand_position(self):
        # type: () -> StandPosition
        """Gets the stand_position of this Action.  # noqa: E501


        :return: The stand_position of this Action.  # noqa: E501
        :rtype: StandPosition
        """
        return self._stand_position

    @stand_position.setter
    def stand_position(self, stand_position):
        # type: (StandPosition) -> None
        """Sets the stand_position of this Action.


        :param stand_position: The stand_position of this Action.  # noqa: E501
        :type stand_position: StandPosition
        :rtype: None
        """

        self._stand_position = stand_position

    @property
    def stop_duration(self):
        # type: () -> int
        """Gets the stop_duration of this Action.  # noqa: E501

        The duration to wait (seconds) until stopping only used for 'type=stop'  # noqa: E501

        :return: The stop_duration of this Action.  # noqa: E501
        :rtype: int
        """
        return self._stop_duration

    @stop_duration.setter
    def stop_duration(self, stop_duration):
        # type: (int) -> None
        """Sets the stop_duration of this Action.

        The duration to wait (seconds) until stopping only used for 'type=stop'  # noqa: E501

        :param stop_duration: The stop_duration of this Action.  # noqa: E501
        :type stop_duration: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and stop_duration is not None
            and stop_duration < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `stop_duration`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._stop_duration = stop_duration

    @property
    def tone_name(self):
        # type: () -> str
        """Gets the tone_name of this Action.  # noqa: E501

        Name of the tone only used for 'type=tone'  # noqa: E501

        :return: The tone_name of this Action.  # noqa: E501
        :rtype: str
        """
        return self._tone_name

    @tone_name.setter
    def tone_name(self, tone_name):
        # type: (str) -> None
        """Sets the tone_name of this Action.

        Name of the tone only used for 'type=tone'  # noqa: E501

        :param tone_name: The tone_name of this Action.  # noqa: E501
        :type tone_name: str
        :rtype: None
        """
        allowed_values = [None, "alarm_1", "alarm_2"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and tone_name not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `tone_name` ({0}), must be one of {1}".format(  # noqa: E501
                    tone_name, allowed_values
                )
            )

        self._tone_name = tone_name

    LTypeType = Literal[
        "standby",
        "tone",
        "radio",
        "sourcePreset",
        "deezerFlow",
        "activateSource",
        "playQueue",
        "buttonShortPress",
        "allStandby",
        "touchToJoin",
        "fallback",
        "volume",
        "stop",
        "triggerContent",
        "speakerGroup",
        "listeningMode",
        "stand",
    ]

    @property
    def type(self):
        # type: () -> 'Action.LTypeType'
        """Gets the type of this Action.  # noqa: E501

        The type of Action  # noqa: E501

        :return: The type of this Action.  # noqa: E501
        :rtype: 'Action.LTypeType'
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: ('Action.LTypeType') -> None
        """Sets the type of this Action.

        The type of Action  # noqa: E501

        :param type: The type of this Action.  # noqa: E501
        :type type: 'Action.LTypeType'
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and type is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "standby",
            "tone",
            "radio",
            "sourcePreset",
            "deezerFlow",
            "activateSource",
            "playQueue",
            "buttonShortPress",
            "allStandby",
            "touchToJoin",
            "fallback",
            "volume",
            "stop",
            "triggerContent",
            "speakerGroup",
            "listeningMode",
            "stand",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and type not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def volume_level(self):
        # type: () -> int
        """Gets the volume_level of this Action.  # noqa: E501

        The volume level to configure only used for 'type=volume'  # noqa: E501

        :return: The volume_level of this Action.  # noqa: E501
        :rtype: int
        """
        return self._volume_level

    @volume_level.setter
    def volume_level(self, volume_level):
        # type: (int) -> None
        """Sets the volume_level of this Action.

        The volume level to configure only used for 'type=volume'  # noqa: E501

        :param volume_level: The volume_level of this Action.  # noqa: E501
        :type volume_level: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and volume_level is not None
            and volume_level > 100
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `volume_level`, must be a value less than or equal to `100`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and volume_level is not None
            and volume_level < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `volume_level`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._volume_level = volume_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Action):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Action):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.software_update_status import SoftwareUpdateStatus  # noqa: E501
from mozart_api.rest import ApiException


class TestSoftwareUpdateStatus(unittest.TestCase):
    """SoftwareUpdateStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SoftwareUpdateStatus
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.software_update_status.SoftwareUpdateStatus()  # noqa: E501
        if include_optional:
            return SoftwareUpdateStatus(
                available_update="0",
                last_check=datetime.datetime.strptime(
                    "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                ),
                last_update=datetime.datetime.strptime(
                    "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                ),
                software_version="0",
                state=mozart_api.models.software_update_state.SoftwareUpdateState(
                    seconds_remaining=56,
                    value="idle",
                ),
                update_progress=56,
            )
        else:
            return SoftwareUpdateStatus(
                software_version="0",
                state=mozart_api.models.software_update_state.SoftwareUpdateState(
                    seconds_remaining=56,
                    value="idle",
                ),
            )

    def testSoftwareUpdateStatus(self):
        """Test SoftwareUpdateStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.software_update_api import SoftwareUpdateApi  # noqa: E501
from mozart_api.rest import ApiException


class TestSoftwareUpdateApi(unittest.TestCase):
    """SoftwareUpdateApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.software_update_api.SoftwareUpdateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_softwareupdate_status(self):
        """Test case for get_softwareupdate_status

        Get the current software update status  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class RemoteUIKeyState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"state": "str"}

    attribute_map = {"state": "state"}

    def __init__(
        self,
        state: Optional["RemoteUIKeyState.LTypeState"] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RemoteUIKeyState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._state = None
        self.discriminator = None

        if state is not None:
            self.state = state

    LTypeState = Literal["ShortPress", "LongPress", "Down", "Continue", "Release"]

    @property
    def state(self):
        # type: () -> 'RemoteUIKeyState.LTypeState'
        """Gets the state of this RemoteUIKeyState.  # noqa: E501

        The state of the pressed key. ShortPress and LongPress's duration are determined by the remote. Whereas Down, Continue, and Release reflect the state of the key and press duration is the time between a Down and a Release state. Continue indicates that a button is pressed and the key event should be handled multiple times until a release is received.   # noqa: E501

        :return: The state of this RemoteUIKeyState.  # noqa: E501
        :rtype: 'RemoteUIKeyState.LTypeState'
        """
        return self._state

    @state.setter
    def state(self, state):
        # type: ('RemoteUIKeyState.LTypeState') -> None
        """Sets the state of this RemoteUIKeyState.

        The state of the pressed key. ShortPress and LongPress's duration are determined by the remote. Whereas Down, Continue, and Release reflect the state of the key and press duration is the time between a Down and a Release state. Continue indicates that a button is pressed and the key event should be handled multiple times until a release is received.   # noqa: E501

        :param state: The state of this RemoteUIKeyState.  # noqa: E501
        :type state: 'RemoteUIKeyState.LTypeState'
        :rtype: None
        """
        allowed_values = [
            "ShortPress",
            "LongPress",
            "Down",
            "Continue",
            "Release",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and state not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}".format(  # noqa: E501
                    state, allowed_values
                )
            )

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RemoteUIKeyState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RemoteUIKeyState):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.bass_management import BassManagement

from mozart_api.configuration import Configuration


class BassManagementRange(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"default": "BassManagement", "range": "list[BassManagement]"}

    attribute_map = {"default": "default", "range": "range"}

    def __init__(
        self,
        default: Optional[BassManagement] = None,
        range: Optional[List[BassManagement]] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """BassManagementRange - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._default = None
        self._range = None
        self.discriminator = None

        self.default = default
        self.range = range

    @property
    def default(self):
        # type: () -> BassManagement
        """Gets the default of this BassManagementRange.  # noqa: E501


        :return: The default of this BassManagementRange.  # noqa: E501
        :rtype: BassManagement
        """
        return self._default

    @default.setter
    def default(self, default):
        # type: (BassManagement) -> None
        """Sets the default of this BassManagementRange.


        :param default: The default of this BassManagementRange.  # noqa: E501
        :type default: BassManagement
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and default is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `default`, must not be `None`"
            )  # noqa: E501

        self._default = default

    @property
    def range(self):
        # type: () -> List[BassManagement]
        """Gets the range of this BassManagementRange.  # noqa: E501

        bass-management range  # noqa: E501

        :return: The range of this BassManagementRange.  # noqa: E501
        :rtype: List[BassManagement]
        """
        return self._range

    @range.setter
    def range(self, range):
        # type: (list[BassManagement]) -> None
        """Sets the range of this BassManagementRange.

        bass-management range  # noqa: E501

        :param range: The range of this BassManagementRange.  # noqa: E501
        :type range: list[BassManagement]
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and range is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `range`, must not be `None`"
            )  # noqa: E501

        self._range = range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BassManagementRange):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BassManagementRange):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.room_compensation_state import (
    RoomCompensationState,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestRoomCompensationState(unittest.TestCase):
    """RoomCompensationState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RoomCompensationState
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.room_compensation_state.RoomCompensationState()  # noqa: E501
        if include_optional:
            return RoomCompensationState(
                state="notStarted",
                error="noError",
                error_details=mozart_api.models.room_compensation_error_details.RoomCompensationErrorDetails(
                    error_list=[
                        mozart_api.models.room_compensation_measurement_error.RoomCompensationMeasurementError(
                            error="noError",
                            speaker_id="FrontLeft",
                        )
                    ],
                ),
                last_run_available=True,
                properties=null,
                time_stamp=datetime.datetime.strptime(
                    "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                ),
            )
        else:
            return RoomCompensationState()

    def testRoomCompensationState(self):
        """Test RoomCompensationState"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class Art(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "has_local_image": "bool",
        "key": "str",
        "size": "str",
        "type": "str",
        "url": "str",
    }

    attribute_map = {
        "has_local_image": "hasLocalImage",
        "key": "key",
        "size": "size",
        "type": "type",
        "url": "url",
    }

    def __init__(
        self,
        has_local_image: Optional[bool] = None,
        key: Optional[str] = None,
        size: Optional[str] = None,
        type: Optional[str] = None,
        url: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Art - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._has_local_image = None
        self._key = None
        self._size = None
        self._type = None
        self._url = None
        self.discriminator = None

        if has_local_image is not None:
            self.has_local_image = has_local_image
        if key is not None:
            self.key = key
        if size is not None:
            self.size = size
        if type is not None:
            self.type = type
        if url is not None:
            self.url = url

    @property
    def has_local_image(self):
        # type: () -> bool
        """Gets the has_local_image of this Art.  # noqa: E501


        :return: The has_local_image of this Art.  # noqa: E501
        :rtype: bool
        """
        return self._has_local_image

    @has_local_image.setter
    def has_local_image(self, has_local_image):
        # type: (bool) -> None
        """Sets the has_local_image of this Art.


        :param has_local_image: The has_local_image of this Art.  # noqa: E501
        :type has_local_image: bool
        :rtype: None
        """

        self._has_local_image = has_local_image

    @property
    def key(self):
        # type: () -> str
        """Gets the key of this Art.  # noqa: E501


        :return: The key of this Art.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        # type: (str) -> None
        """Sets the key of this Art.


        :param key: The key of this Art.  # noqa: E501
        :type key: str
        :rtype: None
        """

        self._key = key

    @property
    def size(self):
        # type: () -> str
        """Gets the size of this Art.  # noqa: E501


        :return: The size of this Art.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        # type: (str) -> None
        """Sets the size of this Art.


        :param size: The size of this Art.  # noqa: E501
        :type size: str
        :rtype: None
        """

        self._size = size

    @property
    def type(self):
        # type: () -> str
        """Gets the type of this Art.  # noqa: E501


        :return: The type of this Art.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: (str) -> None
        """Sets the type of this Art.


        :param type: The type of this Art.  # noqa: E501
        :type type: str
        :rtype: None
        """

        self._type = type

    @property
    def url(self):
        # type: () -> str
        """Gets the url of this Art.  # noqa: E501


        :return: The url of this Art.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        # type: (str) -> None
        """Sets the url of this Art.


        :param url: The url of this Art.  # noqa: E501
        :type url: str
        :rtype: None
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Art):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Art):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.room_compensation_error_details import (
    RoomCompensationErrorDetails,
)
from mozart_api.models.room_compensation_properties import RoomCompensationProperties

from mozart_api.configuration import Configuration


class RoomCompensationState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "state": "str",
        "error": "str",
        "error_details": "RoomCompensationErrorDetails",
        "last_run_available": "bool",
        "properties": "RoomCompensationProperties",
        "time_stamp": "datetime",
    }

    attribute_map = {
        "state": "state",
        "error": "error",
        "error_details": "errorDetails",
        "last_run_available": "lastRunAvailable",
        "properties": "properties",
        "time_stamp": "timeStamp",
    }

    def __init__(
        self,
        state: Optional["RoomCompensationState.LTypeState"] = None,
        error: Optional["RoomCompensationState.LTypeError"] = None,
        error_details: Optional[RoomCompensationErrorDetails] = None,
        last_run_available: Optional[bool] = None,
        properties: Optional[RoomCompensationProperties] = None,
        time_stamp: Optional[datetime] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RoomCompensationState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._state = None
        self._error = None
        self._error_details = None
        self._last_run_available = None
        self._properties = None
        self._time_stamp = None
        self.discriminator = None

        if state is not None:
            self.state = state
        if error is not None:
            self.error = error
        if error_details is not None:
            self.error_details = error_details
        if last_run_available is not None:
            self.last_run_available = last_run_available
        if properties is not None:
            self.properties = properties
        if time_stamp is not None:
            self.time_stamp = time_stamp

    LTypeState = Literal["notStarted", "running", "done", "error", "stopped"]

    @property
    def state(self):
        # type: () -> 'RoomCompensationState.LTypeState'
        """Gets the state of this RoomCompensationState.  # noqa: E501


        :return: The state of this RoomCompensationState.  # noqa: E501
        :rtype: 'RoomCompensationState.LTypeState'
        """
        return self._state

    @state.setter
    def state(self, state):
        # type: ('RoomCompensationState.LTypeState') -> None
        """Sets the state of this RoomCompensationState.


        :param state: The state of this RoomCompensationState.  # noqa: E501
        :type state: 'RoomCompensationState.LTypeState'
        :rtype: None
        """
        allowed_values = [
            "notStarted",
            "running",
            "done",
            "error",
            "stopped",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and state not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}".format(  # noqa: E501
                    state, allowed_values
                )
            )

        self._state = state

    LTypeError = Literal[
        "noError",
        "microphoneMuted",
        "microphoneSwitchOff",
        "microphoneSignalMissing",
        "externalMicrophoneMissing",
        "externalMicrophoneInvalidPosition",
        "noisyEnvironment",
        "speakerMeasurementFailed",
        "invalidSpeakerList",
        "invalidAction",
        "internalError",
    ]

    @property
    def error(self):
        # type: () -> 'RoomCompensationState.LTypeError'
        """Gets the error of this RoomCompensationState.  # noqa: E501

        microphoneMuted:   The microphone is muted (soft-off, using touch button). microphoneSwitchOff:   The microphone switch is set in its off position. microphoneSignalMissing:   No signal was detected. Is the microphone blocked? externalMicrophoneMissing:   The external microphone is not connected.   Is only relevant for advanced room compensation. externalMicrophoneInvalidPosition:   The external microphone is placed in an invalid position,   e.g. placed too close or in an extreme angle to the internal speakers.   Is only relevant for advanced room compensation. noisyEnvironment:   Too much environment noise to get a valid measurement. speakerMeasurementFailed:   A measurement failed, related to one of the individual speakers.   See the errorDetails property for details about the error and which speaker measurement failed.   Is only relevant for advanced room compensation. invalidSpeakerList:   The speaker list contains invalid speakers.   Valid speakers are: all external speakers and non-virtual internal speakers.   Is only relevant for advanced room compensation. invalidAction:   Could not start with given action.   Eg. can't run from last failed speaker if there isn't any failed run.   Is only relevant for advanced room compensation. internalError:   Internal product error.   # noqa: E501

        :return: The error of this RoomCompensationState.  # noqa: E501
        :rtype: 'RoomCompensationState.LTypeError'
        """
        return self._error

    @error.setter
    def error(self, error):
        # type: ('RoomCompensationState.LTypeError') -> None
        """Sets the error of this RoomCompensationState.

        microphoneMuted:   The microphone is muted (soft-off, using touch button). microphoneSwitchOff:   The microphone switch is set in its off position. microphoneSignalMissing:   No signal was detected. Is the microphone blocked? externalMicrophoneMissing:   The external microphone is not connected.   Is only relevant for advanced room compensation. externalMicrophoneInvalidPosition:   The external microphone is placed in an invalid position,   e.g. placed too close or in an extreme angle to the internal speakers.   Is only relevant for advanced room compensation. noisyEnvironment:   Too much environment noise to get a valid measurement. speakerMeasurementFailed:   A measurement failed, related to one of the individual speakers.   See the errorDetails property for details about the error and which speaker measurement failed.   Is only relevant for advanced room compensation. invalidSpeakerList:   The speaker list contains invalid speakers.   Valid speakers are: all external speakers and non-virtual internal speakers.   Is only relevant for advanced room compensation. invalidAction:   Could not start with given action.   Eg. can't run from last failed speaker if there isn't any failed run.   Is only relevant for advanced room compensation. internalError:   Internal product error.   # noqa: E501

        :param error: The error of this RoomCompensationState.  # noqa: E501
        :type error: 'RoomCompensationState.LTypeError'
        :rtype: None
        """
        allowed_values = [
            "noError",
            "microphoneMuted",
            "microphoneSwitchOff",
            "microphoneSignalMissing",
            "externalMicrophoneMissing",
            "externalMicrophoneInvalidPosition",
            "noisyEnvironment",
            "speakerMeasurementFailed",
            "invalidSpeakerList",
            "invalidAction",
            "internalError",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and error not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `error` ({0}), must be one of {1}".format(  # noqa: E501
                    error, allowed_values
                )
            )

        self._error = error

    @property
    def error_details(self):
        # type: () -> RoomCompensationErrorDetails
        """Gets the error_details of this RoomCompensationState.  # noqa: E501


        :return: The error_details of this RoomCompensationState.  # noqa: E501
        :rtype: RoomCompensationErrorDetails
        """
        return self._error_details

    @error_details.setter
    def error_details(self, error_details):
        # type: (RoomCompensationErrorDetails) -> None
        """Sets the error_details of this RoomCompensationState.


        :param error_details: The error_details of this RoomCompensationState.  # noqa: E501
        :type error_details: RoomCompensationErrorDetails
        :rtype: None
        """

        self._error_details = error_details

    @property
    def last_run_available(self):
        # type: () -> bool
        """Gets the last_run_available of this RoomCompensationState.  # noqa: E501

        When true, measurements have been cached due to manual interrupt or failure, making it possible to use the action \"continue\" where the system will continue from the speaker where interrupted. The cached measurements are only temporary and will be cleared after some time (default 15min), in which case lastRunAvailable becomes false.   # noqa: E501

        :return: The last_run_available of this RoomCompensationState.  # noqa: E501
        :rtype: bool
        """
        return self._last_run_available

    @last_run_available.setter
    def last_run_available(self, last_run_available):
        # type: (bool) -> None
        """Sets the last_run_available of this RoomCompensationState.

        When true, measurements have been cached due to manual interrupt or failure, making it possible to use the action \"continue\" where the system will continue from the speaker where interrupted. The cached measurements are only temporary and will be cleared after some time (default 15min), in which case lastRunAvailable becomes false.   # noqa: E501

        :param last_run_available: The last_run_available of this RoomCompensationState.  # noqa: E501
        :type last_run_available: bool
        :rtype: None
        """

        self._last_run_available = last_run_available

    @property
    def properties(self):
        # type: () -> RoomCompensationProperties
        """Gets the properties of this RoomCompensationState.  # noqa: E501


        :return: The properties of this RoomCompensationState.  # noqa: E501
        :rtype: RoomCompensationProperties
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        # type: (RoomCompensationProperties) -> None
        """Sets the properties of this RoomCompensationState.


        :param properties: The properties of this RoomCompensationState.  # noqa: E501
        :type properties: RoomCompensationProperties
        :rtype: None
        """

        self._properties = properties

    @property
    def time_stamp(self):
        # type: () -> datetime
        """Gets the time_stamp of this RoomCompensationState.  # noqa: E501


        :return: The time_stamp of this RoomCompensationState.  # noqa: E501
        :rtype: datetime
        """
        return self._time_stamp

    @time_stamp.setter
    def time_stamp(self, time_stamp):
        # type: (datetime) -> None
        """Sets the time_stamp of this RoomCompensationState.


        :param time_stamp: The time_stamp of this RoomCompensationState.  # noqa: E501
        :type time_stamp: datetime
        :rtype: None
        """

        self._time_stamp = time_stamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomCompensationState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoomCompensationState):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "mozart-api"
VERSION = "2.5.3.123.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "aiohttp",
    "certifi",
    "inflection",
    "python_dateutil",
    "six",
    "urllib3",
    "zeroconf",
]

setup(
    name=NAME,
    version=VERSION,
    description="Mozart platform API",
    author="BangOlufsen",
    author_email="support@bang-olufsen.dk",
    url="https://pypi.org/project/mozart-api/",
    keywords=["OpenAPI", "OpenAPI-Generator", "Mozart platform API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description="""# Mozart platform API

[![License](https://img.shields.io/badge/license-MIT-green)](https://github.com/bang-olufsen/mozart-open-api/blob/main/LICENSE)
[![Version](https://img.shields.io/pypi/v/mozart-api?color=g)](https://pypi.org/project/mozart-api)
[![Downloads](https://img.shields.io/pypi/dm/mozart-api)](https://pypi.org/project/mozart-api)
![Python version](https://img.shields.io/pypi/pyversions/mozart-api)

[![Balance stereo](https://raw.githubusercontent.com/bang-olufsen/mozart-open-api/main/docs/media/balance_stereo.png)](https://www.bang-olufsen.com/en/dk/speakers/beosound-balance-stereo-set?variant=beosound-balance-gva-naturaloak-bundle)

The Mozart API is a REST API with async capabilities and WebSocket notification channel for immediate state information. Currently the API is distributed as a Python package and as an OpenAPI document that can be found in the [Github releases](https://github.com/bang-olufsen/mozart-open-api/releases).

Supported by:

- [Beolab 28](https://www.bang-olufsen.com/en/dk/speakers/beolab-28)
- [Beosound 2 3rd gen](https://www.bang-olufsen.com/en/dk/speakers/beosound-2)
- [Beosound A5](https://www.bang-olufsen.com/en/dk/speakers/beosound-a5)
- [Beosound A9 5th gen](https://www.bang-olufsen.com/en/dk/speakers/beosound-a9)
- [Beosound Balance](https://www.bang-olufsen.com/en/dk/speakers/beosound-balance)
- [Beosound Emerge](https://www.bang-olufsen.com/en/dk/speakers/beosound-emerge)
- [Beosound Level](https://www.bang-olufsen.com/en/dk/speakers/beosound-level)
- [Beosound Theatre](https://www.bang-olufsen.com/en/dk/soundbars/beosound-theatre)

API documentation can be found on the [Github page](https://bang-olufsen.github.io/mozart-open-api).
""",
    long_description_content_type="text/markdown",
    entry_points={
        "console_scripts": ["mozart_api = mozart_api.mozart_cli:MozartApiCli"]
    },
    project_urls={
        "Github": "https://github.com/bang-olufsen/mozart-open-api",
        "Documentation": "https://bang-olufsen.github.io/mozart-open-api/",
        "Bug tracker": "https://github.com/bang-olufsen/mozart-open-api/issues",
    },
    python_requires=">=3.10",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.10",
        "Topic :: Multimedia",
        "Intended Audience :: Developers",
    ],
)



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.speaker_group_member_location import SpeakerGroupMemberLocation

from mozart_api.configuration import Configuration


class SpeakerGroupMember(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "distance": "int",
        "friendly_name": "str",
        "gain": "float",
        "id": "str",
        "location": "SpeakerGroupMemberLocation",
        "redirection_level": "int",
        "role": "str",
        "type": "str",
    }

    attribute_map = {
        "distance": "distance",
        "friendly_name": "friendlyName",
        "gain": "gain",
        "id": "id",
        "location": "location",
        "redirection_level": "redirectionLevel",
        "role": "role",
        "type": "type",
    }

    def __init__(
        self,
        distance: Optional[int] = None,
        friendly_name: Optional[str] = None,
        gain: Optional[float] = None,
        id: Optional[str] = None,
        location: Optional[SpeakerGroupMemberLocation] = None,
        redirection_level: Optional[int] = None,
        role: Optional[str] = None,
        type: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SpeakerGroupMember - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._distance = None
        self._friendly_name = None
        self._gain = None
        self._id = None
        self._location = None
        self._redirection_level = None
        self._role = None
        self._type = None
        self.discriminator = None

        self.distance = distance
        self.friendly_name = friendly_name
        self.gain = gain
        self.id = id
        self.location = location
        self.redirection_level = redirection_level
        self.role = role
        self.type = type

    @property
    def distance(self):
        # type: () -> int
        """Gets the distance of this SpeakerGroupMember.  # noqa: E501

        Distance from listening position in cm  # noqa: E501

        :return: The distance of this SpeakerGroupMember.  # noqa: E501
        :rtype: int
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        # type: (int) -> None
        """Sets the distance of this SpeakerGroupMember.

        Distance from listening position in cm  # noqa: E501

        :param distance: The distance of this SpeakerGroupMember.  # noqa: E501
        :type distance: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and distance is not None
            and distance > 1000
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `distance`, must be a value less than or equal to `1000`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and distance is not None
            and distance < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `distance`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._distance = distance

    @property
    def friendly_name(self):
        # type: () -> str
        """Gets the friendly_name of this SpeakerGroupMember.  # noqa: E501


        :return: The friendly_name of this SpeakerGroupMember.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        # type: (str) -> None
        """Sets the friendly_name of this SpeakerGroupMember.


        :param friendly_name: The friendly_name of this SpeakerGroupMember.  # noqa: E501
        :type friendly_name: str
        :rtype: None
        """

        self._friendly_name = friendly_name

    @property
    def gain(self):
        # type: () -> float
        """Gets the gain of this SpeakerGroupMember.  # noqa: E501

        Level in dB  # noqa: E501

        :return: The gain of this SpeakerGroupMember.  # noqa: E501
        :rtype: float
        """
        return self._gain

    @gain.setter
    def gain(self, gain):
        # type: (float) -> None
        """Sets the gain of this SpeakerGroupMember.

        Level in dB  # noqa: E501

        :param gain: The gain of this SpeakerGroupMember.  # noqa: E501
        :type gain: float
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and gain is not None
            and gain > 6
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `gain`, must be a value less than or equal to `6`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and gain is not None
            and gain < -24
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `gain`, must be a value greater than or equal to `-24`"
            )  # noqa: E501

        self._gain = gain

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this SpeakerGroupMember.  # noqa: E501


        :return: The id of this SpeakerGroupMember.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        # type: (str) -> None
        """Sets the id of this SpeakerGroupMember.


        :param id: The id of this SpeakerGroupMember.  # noqa: E501
        :type id: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and id is None
        ):  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def location(self):
        # type: () -> SpeakerGroupMemberLocation
        """Gets the location of this SpeakerGroupMember.  # noqa: E501


        :return: The location of this SpeakerGroupMember.  # noqa: E501
        :rtype: SpeakerGroupMemberLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        # type: (SpeakerGroupMemberLocation) -> None
        """Sets the location of this SpeakerGroupMember.


        :param location: The location of this SpeakerGroupMember.  # noqa: E501
        :type location: SpeakerGroupMemberLocation
        :rtype: None
        """

        self._location = location

    @property
    def redirection_level(self):
        # type: () -> int
        """Gets the redirection_level of this SpeakerGroupMember.  # noqa: E501

        Redirection level for bass management in dB  # noqa: E501

        :return: The redirection_level of this SpeakerGroupMember.  # noqa: E501
        :rtype: int
        """
        return self._redirection_level

    @redirection_level.setter
    def redirection_level(self, redirection_level):
        # type: (int) -> None
        """Sets the redirection_level of this SpeakerGroupMember.

        Redirection level for bass management in dB  # noqa: E501

        :param redirection_level: The redirection_level of this SpeakerGroupMember.  # noqa: E501
        :type redirection_level: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and redirection_level is not None
            and redirection_level > 6
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `redirection_level`, must be a value less than or equal to `6`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and redirection_level is not None
            and redirection_level < -100
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `redirection_level`, must be a value greater than or equal to `-100`"
            )  # noqa: E501

        self._redirection_level = redirection_level

    @property
    def role(self):
        # type: () -> str
        """Gets the role of this SpeakerGroupMember.  # noqa: E501


        :return: The role of this SpeakerGroupMember.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        # type: (str) -> None
        """Sets the role of this SpeakerGroupMember.


        :param role: The role of this SpeakerGroupMember.  # noqa: E501
        :type role: str
        :rtype: None
        """

        self._role = role

    @property
    def type(self):
        # type: () -> str
        """Gets the type of this SpeakerGroupMember.  # noqa: E501


        :return: The type of this SpeakerGroupMember.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: (str) -> None
        """Sets the type of this SpeakerGroupMember.


        :param type: The type of this SpeakerGroupMember.  # noqa: E501
        :type type: str
        :rtype: None
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpeakerGroupMember):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SpeakerGroupMember):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.power_api import PowerApi  # noqa: E501
from mozart_api.rest import ApiException


class TestPowerApi(unittest.TestCase):
    """PowerApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.power_api.PowerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_battery_state(self):
        """Test case for get_battery_state

        Get battery state of the product  # noqa: E501
        """
        pass

    def test_get_power_state(self):
        """Test case for get_power_state

        Get power state of the product  # noqa: E501
        """
        pass

    def test_post_standby(self):
        """Test case for post_standby

        Put the device in standby  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
